# Changelog

## 0.1.5 (2025-11-12)

Full Changelog: [v0.0.1...v0.1.5](https://github.com/uselark/lark-billing-python/compare/v0.0.1...v0.1.5)

### Bug Fixes

* compat with Python 3.14 ([8f570d6](https://github.com/uselark/lark-billing-python/commit/8f570d61379629798ce7684077b7bc4d6689d398))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([f679809](https://github.com/uselark/lark-billing-python/commit/f6798098e2c58bdad0b80ba5592dda300e2c791e))


### Chores

* **package:** drop Python 3.8 support ([3130a60](https://github.com/uselark/lark-billing-python/commit/3130a60a1d96c92efa510700530009792214b146))
* update SDK settings ([271d60d](https://github.com/uselark/lark-billing-python/commit/271d60d4dc7049f43e9e43512212bf3835bb556c))
* update SDK settings ([5df4f4f](https://github.com/uselark/lark-billing-python/commit/5df4f4f944188391e71b902fdffda8cf74e58a05))
* update SDK settings ([57395da](https://github.com/uselark/lark-billing-python/commit/57395da2b788f7c8a866cb0d3eca768267519d23))
